About
=====

smf-spf is a lightweight, fast and reliable Sendmail milter that
implements the Sender Policy Framework using the libspf2 library. It
checks SPF records to make sure that email messages are authorized by
the domain name that it is coming from.

It is an alternative to the spfmilter, spf-milter and milter-spiff milters.

Features
--------

* External, plaintext configuration file
* Whitelist by IP address (in CIDR notation)
* Whitelist by PTR (reverse DNS) record
* Whitelist by envelope sender
* Whitelist by envelope recipient
* Scalable, tunable, and fast in-memory cache
* SMTP AUTH support
* Experimental RFC 4408 compliance
* Standard Received-SPF: header injection
* Flexible handling of SPF Fail and SoftFail statuses
    * Block messages
    * Quarantine messages
    * Add subject tag to messages

Requirements
------------

* Linux, FreeBSD, or Solaris
* Sendmail v8.11 or higher with milter support
* Sendmail development files
* POSIX threads library
* [libspf2](http://www.libspf2.org/)

Installation
------------

    ./configure
    make
    make install

Edit the /etc/mail/smfs/smf-spf.conf file.


Add these lines to your Sendmail configuration file (usually sendmail.mc):

    define(`confMILTER_MACROS_HELO', confMILTER_MACROS_HELO`, {verify}')dnl
    INPUT_MAIL_FILTER(`smf-spf', `S=unix:/var/run/smfs/smf-spf.sock, T=S:30s;R:1m')dnl

IMPORTANT: make sure that /var/run is not a group writable directory!

IMPORTANT: make sure that libmilter is compiled with
BROKEN_PTHREAD_SLEEP defined. If this symbol is not defined, libmilter
will use sleep() in signal-handler thread, which may cause various
program misbehaviors, including coredumps.

To rebuild Sendmail with this symbol defined, add the following line to
Sendmail/devtools/Site/site.config.m4:

    APPENDDEF(`confENVDEF', `-DBROKEN_PTHREAD_SLEEP')

If you have the smf-zombie, smf-sav and smf-grey milters installed,
the smf-spf milter should be inserted after the smf-zombie, smf-sav
milters and before the smf-grey milter.

Rebuild your Sendmail configuration file and restart Sendmail daemon.

In the quarantine mode SPF Fail/SoftFail e-Mail messages will
be redirected to the specified quarantine mailbox. All envelope
recipients exclude whitelisted will be removed, and inserted into
original e-Mail messages as X-SPF-Original-To: headers.

Note: successfully authenticated senders will bypass all SPF checks.

It's very useful to add these lines to your Sendmail configuration file:

    define(`confPRIVACY_FLAGS', `goaway,noetrn,nobodyreturn,noreceipts')dnl
    define(`confTO_COMMAND', `1m')dnl
    define(`confTO_IDENT', `0s')dnl
    define(`confMAX_DAEMON_CHILDREN', `256')dnl enlarge if it's required
    define(`confCONNECTION_RATE_THROTTLE', `8')dnl enlarge if it's required
    define(`confBAD_RCPT_THROTTLE', `1')dnl Sendmail v8.12+
    FEATURE(`greet_pause', `5000')dnl Sendmail v8.13+

TODO
----

* Whitelist auto reloading
